return <<'END';
0021	0022
0026	002a
003b	0040
005b	0060
007b	007e
00a1	
00a6	00a9
00ab	00af
00b4	
00b6	00b8
00bb	00bf
00d7	
00f7	
02b9	02ba
02c2	02cf
02d2	02df
02e5	02ed
0374	0375
037e	
0384	0385
0387	
058a	
06e9	
0f3a	0f3d
169b	169c
1800	180a
1fbd	
1fbf	1fc1
1fcd	1fcf
1fdd	1fdf
1fed	1fef
1ffd	1ffe
2010	2027
2035	2046
2048	204d
207c	207e
208c	208e
2100	2101
2103	2106
2108	2109
2114	
2116	2118
211e	2123
2125	
2127	
2129	
2132	
213a	
2153	215f
2190	21f3
2200	2211
2214	22f1
2300	2335
237b	
237d	2394
2396	239a
2400	2426
2440	244a
2500	2595
25a0	25f7
2600	2613
2619	2671
2701	2704
2706	2709
270c	2727
2729	274b
274d	
274f	2752
2756	
2758	275e
2761	2767
2776	2794
2798	27af
27b1	27be
2800	28ff
2e80	2e99
2e9b	2ef3
2f00	2fd5
2ff0	2ffb
3001	3004
3008	3020
3030	
3036	3037
303e	303f
309b	309c
30fb	
a490	a4a1
a4a4	a4b3
a4b5	a4c0
a4c2	a4c4
a4c6	
fd3e	fd3f
fe30	fe44
fe49	fe4f
fe51	
fe54	
fe56	fe5e
fe60	fe61
fe64	fe66
fe68	
fe6b	
ff01	ff02
ff06	ff0a
ff1b	ff20
ff3b	ff40
ff5b	ff5e
ff61	ff65
ffe2	ffe4
ffe8	ffee
fffc	fffd
END
